@@ -134,6 +134,20 @@ function addModelListeners(model, vueModel) {
             }
             vueModel[prop] = _.cloneDeep(model.get(prop));
         }));
+    model.on('msg:custom', (content, buffers) => {
+        if (!content['method']) {
+            return;
+        }
+        const jupyter_method = 'jupyter_' + content['method'];
+        if (!vueModel[jupyter_method]) {
+            return;
+        }
+        let args_ = content['args']
+        if ( args_ == null) {
+            args_ = []
+        }
+        vueModel[jupyter_method](...args_, buffers);
+    });
 }
 
 function createWatches(model, parentView, templateWatchers) {
@@ -163,10 +177,21 @@ function createWatches(model, parentView, templateWatchers) {
 function createMethods(model, parentView) {
     return model.get('events').reduce((result, event) => {
         // eslint-disable-next-line no-param-reassign
-        result[event] = value => model.send(
-            { event, data: eventToObject(value) },
-            model.callbacks(parentView),
-        );
+        result[event] = (value, buffers) => {
+            if (buffers) {
+                const validBuffers = buffers instanceof Array &&
+                    buffers[0] instanceof ArrayBuffer;
+                if (!validBuffers) {
+                    console.warn('second argument is not an BufferArray[View] array')
+                    buffers = undefined;
+                }
+            }
+            model.send(
+                {event, data: eventToObject(value)},
+                model.callbacks(parentView),
+                buffers,
+            );
+        }
         return result;
     }, {});
 }
